import * as vscode from 'vscode';

import { GitService } from './GitService';
import { GViewProvider } from './view.provider';
import { EventBus } from './event-bus';
import { CommitListProvider } from './commit-list.provider';
import { Commander } from './commands';

function getGitApi(){
    
    const gitExtension = vscode.extensions.getExtension<'vscode.git'>('vscode.git');
        if(gitExtension && gitExtension.isActive){
           const api = (gitExtension.exports as any).getAPI(1);
           return api.git.path;
        }else{
           throw new Error('Git extension is not active');
        }
    
}

export async function activate(context: vscode.ExtensionContext) {
    const gitPath = getGitApi();
    if(!gitPath){
        vscode.window.showErrorMessage('No Git avaliable');
        return;
    }
    const logger = vscode.window.createOutputChannel('GitCommitFilter',{log: true});
    const eventBus = new EventBus();
    const gitService = new GitService(gitPath,logger);
    const commitlist = new CommitListProvider(gitService,eventBus)
    
    const commander = new Commander(gitService,eventBus);
    context.subscriptions.push(vscode.commands.registerCommand('gitcommitfilter.showaslist', () => {
        commander.changeToList();
    }));
    context.subscriptions.push(vscode.commands.registerCommand('gitcommitfilter.showastree', () => {
        commander.changeToTree();
    }));
    context.subscriptions.push(vscode.commands.registerCommand('gitcommitfilter.compare', (commit, file) => {
        commander.compare(commit, file);
    }));
      //get view gitcommitfilter.commit-list
    const viewProvider = new GViewProvider(context, gitService,logger);
    const d= vscode.window.registerTreeDataProvider('gitcommitfilter.commit-list', commitlist);
    context.subscriptions.push(d);
    commitlist.refresh();

    const activityBarIcon = vscode.window.registerWebviewViewProvider(GViewProvider.viewType, viewProvider);

    context.subscriptions.push(activityBarIcon);
}

export function deactivate() {}

